@@ -342,7 +342,7 @@ examples:
 helps['acr login'] = """
 type: command
 short-summary: Log in to an Azure Container Registry through the Docker CLI.
-long-summary: Docker must be installed on your machine. Once done, use `docker logout <registry url>` to log out. (If you only need an access token and do not want to install Docker, specify '--expose-token')
+long-summary: Docker must be installed on your machine. Once done, use `docker logout <registry url>` to log out. (If you only need a refresh token and do not want to install Docker, specify '--expose-token')
 examples:
   - name: Log in to an Azure Container Registry
     text: >
@@ -898,6 +898,12 @@ examples:
   - name: Get the storage usage for an Azure Container Registry.
     text: >
         az acr show-usage -n myregistry
+  - name: Get the current amount of storage used by the registry based on the included storage of its SKU (in bytes).
+    text: >
+        az acr show-usage -n myregistry --query "value[?name=='Size'] | [0]"
+  - name: Get the current amount of storage used by the registry and the maximum storage capacity allowed.
+    text: >
+        az acr show-usage -n myregistry --query "value[?name=='MaximumStorageCapacity'] | [0]"
 """
 
 helps['acr task'] = """
