@@ -141,11 +141,12 @@ class AFDProfileCreate(_AFDProfileCreate):
         )
         args_schema.user_assigned_identities.Element = AAZStrArg()
         args_schema.location._registered = False
+        args_schema.location._required = False
         return args_schema
 
     def pre_operations(self):
         args = self.ctx.args
-        args.location = 'global'
+        args.location = 'global'  # AFD profile location is always global
         user_assigned_identities = {}
         for identity in args.user_assigned_identities:
             user_assigned_identities[identity.to_serialized_data()] = {}
@@ -180,7 +181,6 @@ class AFDProfileUpdate(_AFDProfileUpdate):
             'The dictionary values can be empty objects ({{}}) in requests.',
         )
         args_schema.user_assigned_identities.Element = AAZStrArg()
-        args_schema.location._registered = False
         args_schema.sku._registered = False
         return args_schema
 
@@ -193,8 +193,6 @@ class AFDProfileUpdate(_AFDProfileUpdate):
         if existing['sku']['name'] not in (SkuName.premium_azure_front_door, SkuName.standard_azure_front_door):
             logger.warning('Unexpected SKU type, only Standard_AzureFrontDoor and Premium_AzureFrontDoor are supported')
             raise ResourceNotFoundError("Operation returned an invalid status code 'Not Found'")
-        existing_location = None if 'location' not in existing else existing['location']
-        args.location = existing_location
 
         if has_value(args.identity_type):
             user_assigned_identities = {}
@@ -240,19 +238,43 @@ class AFDEndpointUpdate(_AFDEndpointUpdate):
     @classmethod
     def _build_arguments_schema(cls, *args, **kwargs):
         args_schema = super()._build_arguments_schema(*args, **kwargs)
-        args_schema.location._registered = False
         args_schema.name_reuse_scope._registered = False
         return args_schema
 
-    def pre_operations(self):
-        args = self.ctx.args
-        existing = _AFDEndpointShow(cli_ctx=self.cli_ctx)(command_args={
-            'resource_group': args.resource_group,
-            'profile_name': args.profile_name,
-            'endpoint_name': args.endpoint_name
-        })
-        existing_location = None if 'location' not in existing else existing['location']
-        args.location = existing_location
+
+def get_health_probe_settings(enable_health_probe, probe_interval_in_seconds,
+                              probe_path, probe_protocol, probe_request_type):
+    params = [probe_interval_in_seconds, probe_path, probe_protocol, probe_request_type]
+    if enable_health_probe is False:
+        return None
+    if enable_health_probe is True:
+        if any(param is None for param in params):
+            raise InvalidArgumentValueError(
+                'When --enable-health-probe is set, all of --probe-interval-in-seconds, --probe-path, '
+                '--probe-protocol and --probe-request-type must be specified.'
+            )
+    elif any(param is not None for param in params):
+        enable_health_probe = True
+        if any(param is None for param in params):
+            raise InvalidArgumentValueError(
+                'When --enable-health-probe is set, all of --probe-interval-in-seconds, --probe-path, '
+                '--probe-protocol and --probe-request-type must be specified.'
+            )
+    else:
+        enable_health_probe = False
+        if any(param is not None for param in params):
+            raise InvalidArgumentValueError(
+                'When --enable-health-probe is not set, none of --probe-interval-in-seconds, --probe-path, '
+                '--probe-protocol and --probe-request-type can be specified.'
+            )
+        return None
+
+    return {
+        'probeIntervalInSeconds': probe_interval_in_seconds,
+        'probePath': probe_path,
+        'probeProtocol': probe_protocol,
+        'probeRequestType': probe_request_type
+    }
 
 
 class AFDOriginGroupCreate(_AFDOriginGroupCreate):
@@ -294,10 +316,14 @@ class AFDOriginGroupCreate(_AFDOriginGroupCreate):
 
     def pre_operations(self):
         args = self.ctx.args
+
+        enable_health_probe = None
         probe_interval_in_seconds = None
         probe_path = None
         probe_protocol = None
         probe_request_type = None
+        if has_value(args.enable_health_probe):
+            enable_health_probe = args.enable_health_probe.to_serialized_data()
         if has_value(args.probe_interval_in_seconds):
             probe_interval_in_seconds = args.probe_interval_in_seconds.to_serialized_data()
         if has_value(args.probe_path):
@@ -306,15 +332,14 @@ class AFDOriginGroupCreate(_AFDOriginGroupCreate):
             probe_protocol = args.probe_protocol.to_serialized_data()
         if has_value(args.probe_request_type):
             probe_request_type = args.probe_request_type.to_serialized_data()
-        args.health_probe_settings = {
-            'probeIntervalInSeconds': probe_interval_in_seconds,
-            'probePath': probe_path,
-            'probeProtocol': probe_protocol,
-            'probeRequestType': probe_request_type
-        }
 
-        if args.enable_health_probe.to_serialized_data() is False:
-            args.health_probe_settings = None
+        args.health_probe_settings = get_health_probe_settings(
+            enable_health_probe,
+            probe_interval_in_seconds,
+            probe_path,
+            probe_protocol,
+            probe_request_type
+        )
 
 
 class AFDOriginGroupUpdate(_AFDOriginGroupUpdate):
@@ -362,6 +387,7 @@ class AFDOriginGroupUpdate(_AFDOriginGroupUpdate):
             'origin_group_name': args.origin_group_name
         })
 
+        enable_health_probe = None
         probe_interval_in_seconds = None
         probe_path = None
         probe_protocol = None
@@ -369,65 +395,43 @@ class AFDOriginGroupUpdate(_AFDOriginGroupUpdate):
 
         if not has_value(args.enable_health_probe):
             if 'healthProbeSettings' not in existing:
-                args.enable_health_probe = False
+                enable_health_probe = False
             else:
-                args.enable_health_probe = True
-                if has_value(args.probe_path):
-                    probe_path = args.probe_path.to_serialized_data()
-                elif 'probePath' in existing['healthProbeSettings']:
-                    probe_path = existing['healthProbeSettings']['probePath']
-
-                if has_value(args.probe_protocol):
-                    probe_protocol = args.probe_protocol.to_serialized_data()
-                elif 'probeProtocol' in existing['healthProbeSettings']:
-                    probe_protocol = existing['healthProbeSettings']['probeProtocol']
-
-                if has_value(args.probe_interval_in_seconds):
-                    probe_interval_in_seconds = args.probe_interval_in_seconds.to_serialized_data()
-                elif 'probeIntervalInSeconds' in existing['healthProbeSettings']:
-                    probe_interval_in_seconds = existing['healthProbeSettings']['probeIntervalInSeconds']
-
-                if has_value(args.probe_request_type):
-                    probe_request_type = args.probe_request_type.to_serialized_data()
-                elif 'probeRequestType' in existing['healthProbeSettings']:
-                    probe_request_type = existing['healthProbeSettings']['probeRequestType']
-
-                args.health_probe_settings = {
-                    'probeIntervalInSeconds': probe_interval_in_seconds,
-                    'probePath': probe_path,
-                    'probeProtocol': probe_protocol,
-                    'probeRequestType': probe_request_type
-                }
-        elif args.enable_health_probe.to_serialized_data() is True:
-            args.enable_health_probe = True
-            if has_value(args.probe_path):
-                probe_path = args.probe_path.to_serialized_data()
-            elif 'probePath' in existing['healthProbeSettings']:
-                probe_path = existing['healthProbeSettings']['probePath']
-
-            if has_value(args.probe_protocol):
-                probe_protocol = args.probe_protocol.to_serialized_data()
-            elif 'probeProtocol' in existing['healthProbeSettings']:
-                probe_protocol = existing['healthProbeSettings']['probeProtocol']
-
-            if has_value(args.probe_interval_in_seconds):
-                probe_interval_in_seconds = args.probe_interval_in_seconds.to_serialized_data()
-            elif 'probeIntervalInSeconds' in existing['healthProbeSettings']:
-                probe_interval_in_seconds = existing['healthProbeSettings']['probeIntervalInSeconds']
-
-            if has_value(args.probe_request_type):
-                probe_request_type = args.probe_request_type.to_serialized_data()
-            elif 'probeRequestType' in existing['healthProbeSettings']:
-                probe_request_type = existing['healthProbeSettings']['probeRequestType']
-
-            args.health_probe_settings = {
-                'probeIntervalInSeconds': probe_interval_in_seconds,
-                'probePath': probe_path,
-                'probeProtocol': probe_protocol,
-                'probeRequestType': probe_request_type
-            }
+                enable_health_probe = True
         else:
-            args.health_probe_settings = None
+            enable_health_probe = args.enable_health_probe.to_serialized_data()
+
+        if has_value(args.probe_path):
+            enable_health_probe = True
+            probe_path = args.probe_path.to_serialized_data()
+        elif 'probePath' in existing['healthProbeSettings']:
+            probe_path = existing['healthProbeSettings']['probePath']
+
+        if has_value(args.probe_protocol):
+            enable_health_probe = True
+            probe_protocol = args.probe_protocol.to_serialized_data()
+        elif 'probeProtocol' in existing['healthProbeSettings']:
+            probe_protocol = existing['healthProbeSettings']['probeProtocol']
+
+        if has_value(args.probe_interval_in_seconds):
+            enable_health_probe = True
+            probe_interval_in_seconds = args.probe_interval_in_seconds.to_serialized_data()
+        elif 'probeIntervalInSeconds' in existing['healthProbeSettings']:
+            probe_interval_in_seconds = existing['healthProbeSettings']['probeIntervalInSeconds']
+
+        if has_value(args.probe_request_type):
+            enable_health_probe = True
+            probe_request_type = args.probe_request_type.to_serialized_data()
+        elif 'probeRequestType' in existing['healthProbeSettings']:
+            probe_request_type = existing['healthProbeSettings']['probeRequestType']
+
+        args.health_probe_settings = get_health_probe_settings(
+            enable_health_probe,
+            probe_interval_in_seconds,
+            probe_path,
+            probe_protocol,
+            probe_request_type
+        )
 
 
 class AFDOriginCreate(_AFDOriginCreate):
@@ -978,7 +982,13 @@ class AFDRuleCreate(_AFDRuleCreate):
         args.actions = actions
 
 
+# pylint: disable=line-too-long
 class AFDRuleconditionAdd(_AFDRuleUpdate):
+    """Add a match condition to the specified delivery rule.
+
+    :example: Add a match condition to a delivery rule.
+        az afd rule condition add --resource-group MyResourceGroup --profile-name MyFrontDoorProfile --rule-set-name MyRuleSet --rule-name MyRule --match-variable RequestMethod --operator Any --match-values GET HTTP --negate-condition false --transforms Lowercase
+    """
     @classmethod
     def _build_arguments_schema(cls, *args, **kwargs):
         args_schema = super()._build_arguments_schema(*args, **kwargs)
@@ -1032,7 +1042,13 @@ class AFDRuleconditionAdd(_AFDRuleUpdate):
         args.conditions = conditions
 
 
+# pylint: disable=line-too-long
 class AFDRuleconditionRemove(_AFDRuleUpdate):
+    """Remove a condition from the specified delivery rule.
+
+    :example: Remove a condition from a delivery rule.
+        az afd rule condition remove --resource-group MyResourceGroup --profile-name MyFrontDoorProfile --rule-set-name MyRuleSet --rule-name MyRule --index 0
+    """
     @classmethod
     def _build_arguments_schema(cls, *args, **kwargs):
         args_schema = super()._build_arguments_schema(*args, **kwargs)
@@ -1063,7 +1079,13 @@ class AFDRuleconditionRemove(_AFDRuleUpdate):
         args.conditions = conditions
 
 
+# pylint: disable=line-too-long
 class AFDRuleActionCreate(_AFDRuleUpdate):
+    """Update a new delivery rule within the specified rule set.
+
+    :example: Create a new delivery rule with a modify response header action.
+        az afd rule action create --resource-group MyResourceGroup --profile-name MyFrontDoorProfile --rule-set-name MyRuleSet --rule-name MyRule --action-name Redirect --redirect-type "Found" --redirect-protocol "Https" --destination "www.example.com
+    """
     @classmethod
     def _build_arguments_schema(cls, *args, **kwargs):
         args_schema = super()._build_arguments_schema(*args, **kwargs)
@@ -1196,7 +1218,13 @@ class AFDRuleActionCreate(_AFDRuleUpdate):
         args.actions = actions
 
 
+# pylint: disable=line-too-long
 class AFDRuleActionRemove(_AFDRuleUpdate):
+    """Remove an action from the specified delivery rule.
+
+    :example: Remove an action from a delivery rule.
+        az afd rule action remove --resource-group MyResourceGroup --profile-name MyFrontDoorProfile --rule-set-name MyRuleSet --rule-name MyRule --index 0
+    """
     @classmethod
     def _build_arguments_schema(cls, *args, **kwargs):
         args_schema = super()._build_arguments_schema(*args, **kwargs)
@@ -1225,7 +1253,13 @@ class AFDRuleActionRemove(_AFDRuleUpdate):
         args.actions = actions
 
 
+# pylint: disable=line-too-long
 class AFDRuleActionShow(_RuleShow):
+    """Show the actions of a delivery rule.
+
+    :example: Show the actions of a delivery rule.
+        az afd rule action show --resource-group MyResourceGroup --profile-name MyFrontDoorProfile --rule-set-name MyRuleSet --rule-name MyRule
+    """
     @classmethod
     def _build_arguments_schema(cls, *args, **kwargs):
         args_schema = super()._build_arguments_schema(*args, **kwargs)
@@ -1236,7 +1270,13 @@ class AFDRuleActionShow(_RuleShow):
         return existing['actions']
 
 
+# pylint: disable=line-too-long
 class AFDRuleConditionShow(_RuleShow):
+    """Show the conditions of a delivery rule.
+
+    :example: Show the conditions of a delivery rule.
+        az afd rule condition show --resource-group MyResourceGroup --profile-name MyFrontDoorProfile --rule-set-name MyRuleSet --rule-name MyRule
+    """
     @classmethod
     def _build_arguments_schema(cls, *args, **kwargs):
         args_schema = super()._build_arguments_schema(*args, **kwargs)
