@@ -9,7 +9,7 @@ import threading
 import time
 import warnings
 from io import BytesIO
-from typing import Generic, IO, Iterator, Optional, TypeVar
+from typing import Generic, Iterator, Optional, TypeVar
 
 from azure.core.exceptions import DecodeError, HttpResponseError, IncompleteReadError
 from azure.core.tracing.common import with_current_context
@@ -431,7 +431,7 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
                 # Parse the total file size and adjust the download size if ranges
                 # were specified
                 self._file_size = parse_length_from_content_range(response.properties.content_range)
-                if self._file_size is None:
+                if not self._file_size:
                     raise ValueError("Required Content-Range response header is missing or malformed.")
                 # Remove any extra encryption data size from blob size
                 self._file_size = adjust_blob_size_for_encryption(self._file_size, self._encryption_data)
@@ -445,7 +445,7 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
                     self.size = self._file_size
 
             except HttpResponseError as error:
-                if self._start_range is None and error.response and error.response.status_code == 416:
+                if self._start_range is None and error.response.status_code == 416:
                     # Get range will fail on an empty file. If the user did not
                     # request a range, do a regular get request in order to get
                     # any properties.
@@ -574,10 +574,10 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
         is unspecified or is -1, all bytes will be read.
 
         :param size:
-            The number of bytes to download from the stream. Leave unspecified
+            The number of bytes to download from the stream. Leave unsepcified
             or set to -1 to download all bytes.
         :returns:
-            The requested data as bytes or a string if encoding was specified. If
+            The requsted data as bytes or a string if encoding was speicified. If
             the return value is empty, there is no more data to read.
         :rtype: T
         """
@@ -646,12 +646,13 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
             return data.decode(self._encoding)
         return data
 
-    def readall(self) -> T:
+    def readall(self):
+        # type: () -> T
         """
         Read the entire contents of this blob.
         This operation is blocking until all data is downloaded.
 
-        :returns: The requested data as bytes or a string if encoding was specified.
+        :returns: The requsted data as bytes or a string if encoding was speicified.
         :rtype: T
         """
         stream = BytesIO()
@@ -662,12 +663,10 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
         return data
 
     def content_as_bytes(self, max_concurrency=1):
-        """DEPRECATED: Download the contents of this file.
+        """Download the contents of this file.
 
         This operation is blocking until all data is downloaded.
 
-        This method is deprecated, use func:`readall` instead.
-
         :keyword int max_concurrency:
             The number of parallel connections with which to download.
         :rtype: bytes
@@ -680,12 +679,10 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
         return self.readall()
 
     def content_as_text(self, max_concurrency=1, encoding="UTF-8"):
-        """DEPRECATED: Download the contents of this blob, and decode as text.
+        """Download the contents of this blob, and decode as text.
 
         This operation is blocking until all data is downloaded.
 
-        This method is deprecated, use func:`readall` instead.
-
         :keyword int max_concurrency:
             The number of parallel connections with which to download.
         :param str encoding:
@@ -700,7 +697,7 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
         self._encoding = encoding
         return self.readall()
 
-    def readinto(self, stream: IO[T]) -> int:
+    def readinto(self, stream):
         """Download the contents of this file to a stream.
 
         :param stream:
@@ -777,9 +774,7 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
         return remaining_size
 
     def download_to_stream(self, stream, max_concurrency=1):
-        """DEPRECATED: Download the contents of this blob to a stream.
-
-        This method is deprecated, use func:`readinto` instead.
+        """Download the contents of this blob to a stream.
 
         :param stream:
             The stream to download to. This can be an open file-handle,
